@@ -1,6 +1,7 @@
 """
 Walker api functions as a mixin
 """
+from jaseci.api.interface import interface
 from jaseci.actor.walker import walker
 from jaseci.graph.node import node
 from jaseci.actor.sentinel import sentinel
@@ -16,8 +17,28 @@ class walker_api():
     def __init__(self):
         self.spawned_walker_ids = id_list(self)
 
-    def api_walker_register(self, snt: sentinel = None,
-                            code: str = '', encoded: bool = False):
+    @interface.public_api(cli_args=['wlk'])
+    def walker_summon(self, key: str, wlk: walker, nd: node,
+                      ctx: dict = {}, global_sync: bool = True):
+        """
+        Public api for running walkers, namespace key must be provided
+        along with the walker id and node id
+        """
+        if(key not in wlk.namespace_keys().values()):
+            return self.bad_walk_response(
+                ['Not authorized to execute this walker'])
+        if(global_sync):  # Test needed
+            self.sync_walker_from_global_sent(wlk)
+        walk = wlk.duplicate()
+        walk.refresh()
+        walk.prime(nd, prime_ctx=ctx)
+        res = walk.run()
+        walk.destroy()
+        return res
+
+    @interface.private_api(cli_args=['code'])
+    def walker_register(self, snt: sentinel = None,
+                        code: str = '', encoded: bool = False):
         """
         Create blank or code loaded walker and return object
         """
@@ -30,8 +51,9 @@ class walker_api():
         else:
             return [f'Walker not created, invalid code!']
 
-    def api_walker_get(self, wlk: walker, mode: str = 'default',
-                       detailed: bool = False):
+    @interface.private_api(cli_args=['wlk'])
+    def walker_get(self, wlk: walker, mode: str = 'default',
+                   detailed: bool = False):
         """
         Get a walker rendered with specific mode
         Valid modes: {default, code, ir, keys, }
@@ -45,8 +67,9 @@ class walker_api():
         else:
             return wlk.serialize(detailed=detailed)
 
-    def api_walker_set(self, wlk: walker, code: str,
-                       mode: str = 'default'):
+    @interface.private_api(cli_args=['wlk'])
+    def walker_set(self, wlk: walker, code: str,
+                   mode: str = 'default'):
         """
         Set code/ir for a walker
         Valid modes: {code, ir, }
@@ -62,7 +85,8 @@ class walker_api():
         else:
             return [f'{wlk} code issues encountered!']
 
-    def api_walker_list(self, snt: sentinel = None, detailed: bool = False):
+    @interface.private_api()
+    def walker_list(self, snt: sentinel = None, detailed: bool = False):
         """
         List walkers known to sentinel
         """
@@ -71,7 +95,8 @@ class walker_api():
             walks.append(i.serialize(detailed=detailed))
         return walks
 
-    def api_walker_delete(self, wlk: walker, snt: sentinel = None):
+    @interface.private_api(cli_args=['wlk'])
+    def walker_delete(self, wlk: walker, snt: sentinel = None):
         """
         Permanently delete walker with given id
         """
@@ -80,7 +105,8 @@ class walker_api():
         snt.walker_ids.destroy_obj(wlk)
         return [f'Walker {wlkid} successfully deleted']
 
-    def api_walker_spawn_create(self, name: str, snt: sentinel = None):
+    @interface.private_api(cli_args=['name'])
+    def walker_spawn_create(self, name: str, snt: sentinel = None):
         """
         Creates new instance of walker and returns new walker object
         """
@@ -89,23 +115,25 @@ class walker_api():
             if(self.spawned_walker_ids.has_obj_by_name(name)):
                 self.spawned_walker_ids.destroy_obj_by_name(name)
             self.spawned_walker_ids.add_obj(wlk)
-            self.api_alias_register(f'spawned:walker:{name}', wlk.jid)
+            self.alias_register(f'spawned:walker:{name}', wlk.jid)
             return wlk.serialize()
         else:
             return [f'Walker not found!']
 
-    def api_walker_spawn_delete(self, name: str):
+    @interface.private_api(cli_args=['name'])
+    def walker_spawn_delete(self, name: str):
         """
         Delete instance of walker
         """
         if(self.spawned_walker_ids.has_obj_by_name(name)):
             self.spawned_walker_ids.destroy_obj_by_name(name)
-            self.api_alias_delete(f'spawned:walker:{name}')
+            self.alias_delete(f'spawned:walker:{name}')
             return [f'Walker {name} deteled!']
         else:
             return [f'Walker {name} not found!']
 
-    def api_walker_spawn_list(self, detailed: bool = False):
+    @interface.private_api()
+    def walker_spawn_list(self, detailed: bool = False):
         """
         List walkers spawned by master
         """
@@ -114,34 +142,36 @@ class walker_api():
             walks.append(i.serialize(detailed=detailed))
         return walks
 
-    def api_walker_prime(self, wlk: walker, nd: node = None, ctx: dict = {}):
+    @interface.private_api(cli_args=['wlk'])
+    def walker_prime(self, wlk: walker, nd: node = None, ctx: dict = {}):
         """
         Assigns walker to a graph node and primes walker for execution
         """
         wlk.prime(nd, prime_ctx=ctx)
         return [f'Walker primed on node {nd.id}']
 
-    def api_walker_execute(self, wlk: walker, prime: node = None,
-                           ctx: dict = {}):
+    @interface.private_api(cli_args=['wlk'])
+    def walker_execute(self, wlk: walker, prime: node = None,
+                       ctx: dict = {}, profiling: bool = False):
         """
         Executes walker (assumes walker is primed)
         """
         if(prime):
-            self.api_walker_prime(wlk=wlk, nd=prime, ctx=ctx)
-        wlk.run()
-        return wlk.report
+            self.walker_prime(wlk=wlk, nd=prime, ctx=ctx)
+        return wlk.run(profiling=profiling)
 
-    def api_walker_run(self, name: str, nd: node = None, ctx: dict = {},
-                       snt: sentinel = None):
+    @interface.private_api(cli_args=['name'])
+    def walker_run(self, name: str, nd: node = None, ctx: dict = {},
+                   snt: sentinel = None, profiling: bool = False):
         """
         Creates walker instance, primes walker on node, executes walker,
         reports results, and cleans up walker instance.
         """
         wlk = snt.spawn_walker(name, caller=self)
         if(not wlk):
-            return [f'Walker {name} not found!']
-        wlk.prime(nd, prime_ctx=ctx)
-        res = self.api_walker_execute(wlk)
+            return self.bad_walk_response([f'Walker {name} not found!'])
+        res = self.walker_execute(
+            wlk=wlk, prime=nd, ctx=ctx, profiling=profiling)
         wlk.destroy()
         return res
 
@@ -151,3 +181,6 @@ class walker_api():
         """
         for i in self.spawned_walker_ids.obj_list():
             i.destroy()
+
+    def bad_walk_response(self, errors=list()):
+        return {'report': [], 'success': False, 'errors': errors}
